/*
 * This program demonstrates the use of the set class.
 */

#include <fstream>
#include <iostream>
#include <chrono>
#include <vector>
#include <set>
#include <unordered_set>
using namespace std;

/*
 * Returns true if the given vector contains the given string, otherwise false.
 */
bool contains(vector<string>& v, string& s) {
    for (size_t i = 0; i < v.size(); i++) {
        if (v[i] == s) {
            return true;
        }
    }
    return false;
}

/*
 * Reads all words from the given file and counts how many unique words are contained
 * in the file.
 */
void wordCount(string filename) {
    auto start = chrono::steady_clock::now();

    set<string> allWords;
    ifstream input;
    input.open(filename.c_str());
    while(true) {
        string word;
        input >> word;
        if (input.fail()) {
            break;
        }
        allWords.insert(word);
    }

    auto end = chrono::steady_clock::now();
    auto diff = end - start;

    cout << filename << " has " << allWords.size() << " unique words." << endl;
    cout << "Took " << chrono::duration <double, milli> (diff).count() << " ms." << endl;
}


int main() {
    wordCount("shakespeare.txt");
    return 0;
}
